﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Text;

using Lucene.Net.Analysis;
using Lucene.Net.Analysis.Standard;
using Lucene.Net.Documents;
using Lucene.Net.Index;
using Lucene.Net.QueryParsers;
using Lucene.Net.Search;
using Lucene.Net.Store;

using NUnit.Framework;

namespace LearningLucene.Net
{
    [TestFixture]
    public class TestHarness
    {
        private string directory;

        [TestFixtureSetUp]
        public void SetUp( )
        {
            var repository = new Repository();

            directory = "docIndex";
            var stopWords = new List<String>(StandardAnalyzer.STOP_WORDS);
            stopWords.Remove("and");
            var analyzer = new StandardAnalyzer(stopWords.ToArray());
            var indexWriter = new IndexWriter( directory, analyzer, true );

            var information = repository.GetEpisodeInformation();

            foreach ( var index in information )
            {
                var document = new Document();
                document.Add( new Field("ID", index.EpisodeID.ToString(), Field.Store.YES, Field.Index.NO ) );
                document.Add( new Field( "Name", index.Name, Field.Store.YES, Field.Index.TOKENIZED ) );
                document.Add( new Field( "Author", index.Author, Field.Store.YES, Field.Index.TOKENIZED ) );
                indexWriter.AddDocument( document );
            }

            indexWriter.Optimize();
            indexWriter.Flush();
            indexWriter.Close();

        }

        [Test]
        public void Search_for_Nant()
        {

            var searchValue = "Nant";
            var stopWords = new List<String>(StandardAnalyzer.STOP_WORDS);
            stopWords.Remove("and");
            var parser = new QueryParser( "Name", new StandardAnalyzer(stopWords.ToArray()) ).Parse( searchValue );
            var indexSearcher = new IndexSearcher( directory );
            var hits = indexSearcher.Search( parser );

            for ( int i = 0; i < hits.Length(); i++ )
            {
                Debug.WriteLine( hits.Doc( i ).Get( "Name" ) );
            }
        }

        [Test]
        public void Advanced_Search( )
        {
            var searchValue = "\"Research and development\"";
            var stopWords = new List<String>(StandardAnalyzer.STOP_WORDS);
            stopWords.Remove("and");
            var parser = new QueryParser( "Name", new StandardAnalyzer(stopWords.ToArray()) );
            parser.SetDefaultOperator(QueryParser.Operator.AND);
  
            var hits = (new IndexSearcher(directory)).Search(parser.Parse(searchValue));

            for ( int i = 0; i < hits.Length(); i++ )
            {
                Debug.WriteLine( hits.Doc( i ).Get( "Name" ) );
            }
             
        }
    }
}
